import java.awt.Color;

import javax.swing.JFrame;

import prefuse.Constants;
import prefuse.Display;
import prefuse.Visualization;
import prefuse.action.ActionList;
import prefuse.action.RepaintAction;
import prefuse.action.assignment.ColorAction;
import prefuse.action.layout.graph.ForceDirectedLayout;
import prefuse.activity.Activity;
import prefuse.controls.DragControl;
import prefuse.controls.PanControl;
import prefuse.controls.ZoomControl;
import prefuse.controls.ZoomToFitControl;
import prefuse.data.Graph;
import prefuse.data.Table;
import prefuse.data.expression.Predicate;
import prefuse.data.expression.parser.ExpressionParser;
import prefuse.render.DefaultRendererFactory;
import prefuse.render.ShapeRenderer;
import prefuse.util.ColorLib;
import prefuse.visual.VisualItem;
public class NodeDisplay {

	public static void main(String[] args){
		//Node Table
		Table table = new Table();
		table.addColumn("Label", String.class);
		table.addColumn("Description", String.class);
		table.addColumn("NodeID", Integer.class);
		
		int row = table.addRow();
		table.set(row, "Label", "Node 1");
		table.set(row, "Description", "This is the first node");
		table.set(row, "NodeID", 1);

		row = table.addRow();
		table.set(row, "Label", "Node 2");
		table.set(row, "Description", "This is the second node");
		table.set(row, "NodeID", 2);
		
		Graph graph = new Graph(table, false);
		
		
		Table table2 = new Table();
		table2.addColumn("One", String.class);
		table2.addColumn("two", Integer.class);
		row = table2.addRow();
		table2.set(row, "One", "one");
		table2.set(row, "two", 2);
		Graph graph2 = new Graph(table2, false);
		
		//Visualization
		Visualization viz = new Visualization();
		viz.add("graph", graph);
		viz.add("graph2", graph2);
		viz.setInteractive("graph.nodes", null, true);
		viz.setInteractive("graph2.nodes", null, true);
		
		//Shape Renderer
		ShapeRenderer renderer = new ShapeRenderer(80);
		DefaultRendererFactory drf = new DefaultRendererFactory();
		drf.setDefaultRenderer(renderer);

		//Predicate Time?
		Predicate shape = (Predicate)ExpressionParser.parse("NodeID == 1");
		Predicate shape2 = (Predicate)ExpressionParser.parse("NodeID == 2");
		Predicate shape3 = (Predicate)ExpressionParser.parse("two == 2");
		viz.setValue("graph.nodes", shape, VisualItem.SHAPE, new Integer(Constants.SHAPE_HEXAGON));
		viz.setValue("graph.nodes", shape2, VisualItem.SHAPE, new Integer(Constants.SHAPE_ELLIPSE));
		viz.setValue("graph2.nodes", shape3, VisualItem.SHAPE, new Integer(Constants.SHAPE_CROSS));
		
		
		
		//Drawing Actionlist
		ActionList draw = new ActionList();
		draw.add(new ColorAction("graph.nodes", VisualItem.STROKECOLOR, ColorLib.rgb(255, 255,255)));
		draw.add(new ColorAction("graph.nodes", VisualItem.FILLCOLOR, ColorLib.rgb(0, 0,0)));
		draw.add(new ColorAction("graph2.nodes", VisualItem.STROKECOLOR, ColorLib.rgb(0, 255,255)));
		draw.add(new ColorAction("graph2.nodes", VisualItem.FILLCOLOR, ColorLib.rgb(0, 0,0)));

		
		ActionList redraw = new ActionList(Activity.INFINITY);
		redraw.add(new RepaintAction());
		redraw.add(new ForceDirectedLayout("graph"));
		redraw.add(new ForceDirectedLayout("graph2"));
		
		viz.putAction("draw", draw);
		viz.putAction("redraw", redraw);
		
		
		//Build the Display
		Display disp = new Display(viz);
		disp.setSize(800,800);
		disp.setForeground(Color.GRAY);
		disp.setBackground(Color.WHITE);
		
		//Control Listeners
		disp.addControlListener(new DragControl());
		disp.addControlListener(new PanControl());
		disp.addControlListener(new ZoomControl());
		disp.addControlListener(new ZoomToFitControl());
		
		viz.run("draw");
		viz.run("redraw");
		
		JFrame frame = new JFrame("App");
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.add(disp);
		frame.pack();
		frame.setVisible(true);

	}
}


